Initial documentation
=====================

The `config.in` file contains all the settings for the analysis. The only required line is the trajectory file, though it would be good to specify everything, especially since the last version of the code produces trajectories with incorrect number of atoms. 

`config.in`
-----------
```
trajectory <file> # the trajectory file to use
natoms <int> # the number of atoms in each frame. If 0, read from trajectory file
box <lx> <ly> <lz> # the dimensions of the box
zslices <int> # the number of slices in the z direction to take when doing a slice-base analysis, I use 40

# parameters describing the centre density and surface thickness. Obtained from fitting to the density profile the equation given in the MolPhys
delta <double>
zgibbs <double> # Gibbs dividing surface
rhoL <double> # density of the liquid

out <analysis> # output the results of a specific analysis. The types available are:

# slice by slice analysis
out density # density profile
out dipoleMoment # dipole moment profile
out chargeDensity # charge density profile
out omDirection # The PDF of cos(OM, z)

# separate analysis for surface and bulk, need the parameters calculated from fitting the density
out ooDistance 0 10 0.1 # ooDistance between nearest neighbours in surface and bulk regions. Parameters: min max dr
out beadsPDFRegions -4.0 4.0 0.1 # the PDF of the beads in each region (surface and bulk). Parameters: rmin, rmax, dr. Faster than above
out atomsPDFRegions -5.0 5.0 0.1 # same, but for the nearest neighbours
out pmf 2 10 0.05 0.05 # potential of mean force. Parameters: rmin, rmax, dr, dCosBeta
out rdf2d 2 10 0.05 0.05 # g(R, cos(beta)). Parameters: rmin, rmax, dr, dCosBeta
out q # tetrahedral order parameter 
out flatness # flatness order parameter 
out hbondsPDF # the PDF of the number of hydrogen bonds
out nearestNeighbourArrangement 
# the arrangement of nearest neighbours. Splits them into different types of species, calculates atomic and beads PDF for those species. Counts the average number of those species in bulk and interface. 

# Older outputs, not that useful at the moment
# out beadsPDFSlices -4.0 4.0 0.1 # the PDF of the beads for each slice. Parameters: rmin, rmax, dr. SLOW!
# out atomsPDFSlices -5.0 5.0 0.1 # same, but for the nearest atoms
# out hBonds # old statistics about hydrogen bonds
# out rdfCentre 1.25 10 0.05 # the RDF in the centre region. Old code, rdf2d is better
```

Typical workflow
----------------
In order to do the separate analysis for the surface and bulk, you need the density profile
from which you can get the fitting parameters. The script `density_fit.sh` does just that 
and writes the results to `densityFit.out`.

A typical workflow would be:

### Stage 1)
#### `config.in`
```
trajectory …
natoms …
box …
zslices …

out density
out dipoleMoment
out chargeDensity
out omDirection
```

#### Commands
```
java -server -Xmx1G -jar qdanalyse.jar
density_fit.sh
cat densityFit.out >> config.in
```

### Stage 2) 
#### `config.in`
```
trajectory …
natoms …
box …
zslices …

delta …
zgibbs …
rhoL ….

out ooDistance 0 10 0.1 
out beadsPDFRegions -4.0 4.0 0.1
out atomsPDFRegions -5.0 5.0 0.1
out pmf 2 10 0.05 0.05 
out rdf2d 2 10 0.05 0.05 
out q 
out flatness 
out hbondsPDF
out nearestNeighbourArrangement 
```
#### Commands
```
java -server -Xmx1G -jar qdanalyse.jar
```

### Stage 3) 
This stage can be run in parallel with the rest since it operates on the pressure 
rather than trajectory, the actions should be pretty clear.

#### Commands
```
surface_tension.sh pimd_pressure.out > surface_tension.out
moving_average surface_tension.out > surface_tension.ma
running_average surface_tension.out > surface_tension.ra
```