#!/bin/bash
# ==================================================================
# Calculates the running average of each column in a file 
# Usage:running_average datafile blocksize[can ommit, default=100]
# ==================================================================
records=`wc -l $1 | cut -f1 -d ' '`

awk -v blocksize=$2 -v records=$records '
    BEGIN {
	# Default block size is 100
	if(blocksize == "") blocksize = 100
	if(blocksize == 0) blocksize = int(records / 50) * 50 # so then block averaging works

        fields = 0
       
	# for(i=50; i<records; i+=50) {
	#     sum[i] = 0 # sum of the values within one block
	#     block_sum[i] = 0 # sum of block averages so far
	#     sum_squares[i] = 0 # sum of the squares of the blocks averages so far
	#     count[i] = 0 # number of blocks processed
	# }
    }
    NF { # ignore empty records
        fields += 1

        if(NR == 1) {
	    for(f=1; f<=NF; f++) {
		value_sum[f] = 0
		for(i=50; i<records;i+=50) {
		    sum[f,i] = 0
		    block_sum[f,i] = 0
		    sum_squares[f,i] = 0
		    count[f,i] = 0
		}
	    }
	}

	for(f=1; f <=NF; f++) {
	    value_sum[f] += $f
	    for(i=50; i<records; i+=50) {
		sum[f, i] += $f
		if(NR % i == 0) {
		    block_average = sum[f,i] / i
		    block_sum[f, i] += block_average
		    sum_squares[f, i] += block_average * block_average
		    sum[f, i] = 0
		    count[f, i] += 1
      		}
	    }
	}

	if(NR % blocksize == 0) {
	    for(f=1; f <= NF; f++) {
		max_error = 0
	    
		for(i = 50; i < NR; i+=50) {
		    stdev = sqrt(sum_squares[f, i] / count[f, i] - (block_sum[f, i] / count[f, i]) * (block_sum[f, i] / count[f, i]))
		    sterr = stdev / sqrt(count[f, i])
		    if(stdev > max_error) max_error = sterr
		}

		printf "%.4f %4f ", value_sum[f] / fields, max_error
	    }
	    print ""
	}
    }
    END {
	# max_error = 0

	# for(i=50; i < NR; i+=50) { 
	#     stdev = sqrt(sum_squares[i] / count[i] - (block_sum[i] / count[i]) * (block_sum[i] / count[i]))
	#     sterr = stdev / sqrt(count[i])
	#     if(stdev > max_error) max_error = sterr
	# }
	
	# print value_sum / fields, max_error
    }
' $1 
